@@ -25,7 +25,7 @@ import zebrazoom.code.GUI.configFileZebrafishFunctions as configFileZebrafishFun
 import zebrazoom.code.GUI.adjustParameterInsideAlgoFunctions as adjustParameterInsideAlgoFunctions
 import zebrazoom.code.GUI.dataAnalysisGUIFunctions as dataAnalysisGUIFunctions
 import zebrazoom.code.GUI.troubleshootingFunction as troubleshootingFunction
-from zebrazoom.code.GUI.GUI_InitialClasses import FullScreenApp, StartPage, SeveralVideos, VideoToAnalyze, FolderToAnalyze, TailExtremityHE, FolderMultipleROIInitialSelect, ConfigFilePromp, Patience, ZZoutro, ResultsVisualization, EnhanceZZOutput, ViewParameters
+from zebrazoom.code.GUI.GUI_InitialClasses import FullScreenApp, StartPage, SeveralVideos, VideoToAnalyze, FolderToAnalyze, TailExtremityHE, FolderMultipleROIInitialSelect, ConfigFilePromp, Patience, ZZoutro, ResultsVisualization, EnhanceZZOutput, ViewParameters, Error
 from zebrazoom.code.GUI.configFilePrepare import ChooseVideoToCreateConfigFileFor, ChooseGeneralExperiment, FreelySwimmingExperiment, WellOrganisation, NbRegionsOfInterest, CircularOrRectangularWells, NumberOfAnimals, NumberOfAnimals2, NumberOfAnimalsCenterOfMass, IdentifyHeadCenter, IdentifyBodyExtremity, FinishConfig, ChooseCircularWellsLeft, ChooseCircularWellsRight, GoToAdvanceSettings
 from zebrazoom.code.GUI.configFileZebrafish import HeadEmbeded
 from zebrazoom.code.GUI.adjustParameterInsideAlgo import AdujstParamInsideAlgo, AdujstParamInsideAlgoFreelySwim
@@ -57,7 +57,8 @@ class SampleApp(tk.Tk):
         self.numWell = 0
         self.numPoiss = 0
         self.numMouv = 0
-        self.visualization = 0
+        self.visualization = 2
+        self.graphScaling = True
         self.justEnteredViewParameter = 0
         self.dataRef = {}
         self.title_font = tkfont.Font(family='Helvetica', size=18, weight="bold", slant="italic")   
@@ -68,7 +69,7 @@ class SampleApp(tk.Tk):
         container.grid_columnconfigure(0, weight=1) 
         self.container = container
         self.frames = {}
-        for F in (StartPage, SeveralVideos, VideoToAnalyze, ChooseVideoToCreateConfigFileFor, ChooseGeneralExperiment, FreelySwimmingExperiment, WellOrganisation, NbRegionsOfInterest, CircularOrRectangularWells, NumberOfAnimals, NumberOfAnimals2, NumberOfAnimalsCenterOfMass, IdentifyHeadCenter, IdentifyBodyExtremity, ChooseCircularWellsLeft, ChooseCircularWellsRight, FinishConfig, FolderToAnalyze, TailExtremityHE, FolderMultipleROIInitialSelect, ConfigFilePromp, Patience, ZZoutro, ResultsVisualization, EnhanceZZOutput, ViewParameters, HeadEmbeded, AdujstParamInsideAlgo, AdujstParamInsideAlgoFreelySwim, GoToAdvanceSettings, CreateExperimentOrganizationExcel, ChooseExperimentOrganizationExcel, ChooseDataAnalysisMethod, PopulationComparison, BoutClustering, AnalysisOutputFolderPopulation, AnalysisOutputFolderClustering, ChooseVideoToTroubleshootSplitVideo, VideoToTroubleshootSplitVideo):
+        for F in (StartPage, SeveralVideos, VideoToAnalyze, ChooseVideoToCreateConfigFileFor, ChooseGeneralExperiment, FreelySwimmingExperiment, WellOrganisation, NbRegionsOfInterest, CircularOrRectangularWells, NumberOfAnimals, NumberOfAnimals2, NumberOfAnimalsCenterOfMass, IdentifyHeadCenter, IdentifyBodyExtremity, ChooseCircularWellsLeft, ChooseCircularWellsRight, FinishConfig, FolderToAnalyze, TailExtremityHE, FolderMultipleROIInitialSelect, ConfigFilePromp, Patience, ZZoutro, ResultsVisualization, EnhanceZZOutput, ViewParameters, Error, HeadEmbeded, AdujstParamInsideAlgo, AdujstParamInsideAlgoFreelySwim, GoToAdvanceSettings, CreateExperimentOrganizationExcel, ChooseExperimentOrganizationExcel, ChooseDataAnalysisMethod, PopulationComparison, BoutClustering, AnalysisOutputFolderPopulation, AnalysisOutputFolderClustering, ChooseVideoToTroubleshootSplitVideo, VideoToTroubleshootSplitVideo):
             page_name = F.__name__
             frame = F(parent=container, controller=self)
             self.frames[page_name] = frame
@@ -105,13 +106,14 @@ class SampleApp(tk.Tk):
         self.frames['ResultsVisualization'] = frame
         self.show_frame("ResultsVisualization")
 
-    def showValidationVideo(self, numWell, zoom, deb):
-        GUI_InitialFunctions.showValidationVideo(self, numWell, zoom, deb)
+    def showValidationVideo(self, numWell, numAnimal, zoom, deb):
+        GUI_InitialFunctions.showValidationVideo(self, numWell, numAnimal, zoom, deb)
 
-    def printSomeResults(self, numWell, numPoiss, numMouv, changeVisualization=False):
+    def printSomeResults(self, numWell, numPoiss, numMouv, changeVisualization=False, changeScaling=False):
         if changeVisualization:
             self.visualization = int(self.visualization + 1) % 3
-        
+        if changeScaling:
+            self.graphScaling = not(self.graphScaling)
         self.numWell  = int(numWell)
         self.numPoiss = int(numPoiss)
         self.numMouv  = int(numMouv)
@@ -126,7 +128,10 @@ class SampleApp(tk.Tk):
         frame.grid(row=0, column=0, sticky="nsew")
         self.frames['ViewParameters']=frame
         self.show_frame("ViewParameters")
-        
+    
+    def showGraphForAllBoutsCombined(self, numWell, numPoiss, dataRef, visualization, graphScaling):
+        GUI_InitialFunctions.showGraphForAllBoutsCombined(self, numWell, numPoiss, dataRef, visualization, graphScaling)
+
     def exploreResultFolder(self, currentResultFolder):
         GUI_InitialFunctions.exploreResultFolder(self, currentResultFolder)
         
@@ -159,8 +164,8 @@ class SampleApp(tk.Tk):
     def chooseGeneralExperiment(self, controller, freeZebra, headEmbZebra, drosophilia, rodent, other, freeZebra2):
         configFilePrepareFunctions.chooseGeneralExperiment(self, controller, freeZebra, headEmbZebra, drosophilia, rodent, other, freeZebra2)
         
-    def wellOrganisation(self, controller, circular, rectangular, roi, other, multipleROIs):
-        configFilePrepareFunctions.wellOrganisation(self, controller, circular, rectangular, roi, other, multipleROIs)
+    def wellOrganisation(self, controller, circular, rectangular, roi, other, multipleROIs, groupSameSizeAndShapeEquallySpacedWells):
+        configFilePrepareFunctions.wellOrganisation(self, controller, circular, rectangular, roi, other, multipleROIs, groupSameSizeAndShapeEquallySpacedWells)
 
     def regionsOfInterest(self, controller, nbwells):
         configFilePrepareFunctions.regionsOfInterest(self, controller, nbwells)
@@ -220,8 +225,8 @@ optionBackgroundExtractionOption):
     def chooseExperimentOrganizationExcel(self, controller):
       dataAnalysisGUIFunctions.chooseExperimentOrganizationExcel(self, controller)
   
-    def populationComparison(self, controller, BoutDuration, TotalDistance, Speed, NumberOfOscillations, meanTBF, maxAmplitude):
-      dataAnalysisGUIFunctions.populationComparison(self, controller, BoutDuration, TotalDistance, Speed, NumberOfOscillations, meanTBF, maxAmplitude)
+    def populationComparison(self, controller, BoutDuration, TotalDistance, Speed, NumberOfOscillations, meanTBF, maxAmplitude, minNbBendForBoutDetect, discard, keep):
+      dataAnalysisGUIFunctions.populationComparison(self, controller, BoutDuration, TotalDistance, Speed, NumberOfOscillations, meanTBF, maxAmplitude, minNbBendForBoutDetect, discard, keep)
       
     def boutClustering(self, controller, nbClustersToFind, FreelySwimming, HeadEmbeded):
       dataAnalysisGUIFunctions.boutClustering(self, controller, nbClustersToFind, FreelySwimming, HeadEmbeded)
