@@ -3,6 +3,7 @@ import math
 import shutil
 import matplotlib.pyplot as plt
 import pickle
+import numpy as np
 
 def populationComparaison(nameOfFile, resFolder, globParam, conditions, genotypes, outputFolder):
 
@@ -33,6 +34,12 @@ def populationComparaison(nameOfFile, resFolder, globParam, conditions, genotype
         values  = dfParam.loc[indices, parameter].values
         concatenatedValues.append(values)
         labels.append(str(condition) + '\n' + str(genotype))
+    
+    concatenatedValuesWithoutNans = []
+    for toConcat in concatenatedValues:
+      concatenatedValuesWithoutNans.append(np.array([x for x in toConcat if not(math.isnan(x))]))
+    concatenatedValues = concatenatedValuesWithoutNans
+    
     if nbLines == 1:
       tabAx[idx%nbColumns].set_title(parameter)
       tabAx[idx%nbColumns].boxplot(concatenatedValues)
